import uuid

from dataclasses import dataclass, field

@dataclass
class EquipmentClass:

  name: str
  active: bool = field(default=False)
  # generated by server and returned
  id: uuid.UUID = field(default=None)


import json

from cc_py_commons.sns.sns_service import SnsService
from cc_py_commons.utils.logger_v2 import logger

class BookLoadNotification:

  def __init__(self, app_config):
    self._app_config = app_config

  def send(self, load_id, user_id):
    message = '{' + f'"userId" : {user_id}, ' \
                    f'"loadId": "{load_id}", ' \
                    f'"subject" : "{self._app_config.BOOK_LOAD_SNS_SUBJECT}", ' \
                    f'"className":  "{self._app_config.BOOK_LOAD_SNS_CLASS_NAME}"' + '}'
    logger.debug(f"sending BookLoadNotification {message} to {self._app_config.BOOK_LOAD_SNS_TOPIC_ARN}")

    try:
      sns_service = SnsService()
      sns_service.send(self._app_config.BOOK_LOAD_SNS_TOPIC_ARN,
        self._app_config.BOOK_LOAD_SNS_SUBJECT, message)
    except Exception as e:
      logger.exception(f"failed to send message to {self._app_config.BOOK_LOAD_SNS_TOPIC_ARN}: {message} - {e}", e)



import uuid
import datetime
from dataclasses import dataclass, field

from cc_py_commons.lanes.lane import Lane

@dataclass
class CarrierLane:

  carrierId: uuid.UUID
  laneDTO: Lane
  hasBackhaulLane: bool = field(default=False)
  isBackhaulLane: bool = field(default=False)
  createBackhaulLanes: bool = field(default=False)
  deleted: bool = field(default=False)
  weeklyFrequency: int = field(default=False)
  runDaily: bool = field(default=False)
  monday: bool = field(default=False)
  tuesday: bool = field(default=False)
  wednesday: bool = field(default=False)
  thursday: bool = field(default=False)
  friday: bool = field(default=False)
  saturday: bool = field(default=False)
  sunday: bool = field(default=False)
  age: float = field(default=None)
  rating: int = field(default=False)
  rate: int = field(default=False)
  rateUpdatedAt: datetime.date = field(default=None)
  fromCarrier: bool = field(default=False)
  toBeReviewed: bool = field(default=False)


import json

from cc_py_commons.config.env import app_config
from cc_py_commons.sqs.sqs_service import SqsService
from cc_py_commons.utils.logger_v2 import logger

class BookingAssistantFlowEvent:

	def send(self, user_id, load, params, capacity_search_equipments, request_id, auto_invite_details=None):
		'''
		Sends and event to the Booking Assistant Flow SQS queue specified in the config.
		Returns the messageId of the enqueued message for later retrieval.
		'''
		event = {
			'userId': user_id,
			'loadDTO': load,
			'payload': params,
			'capacitySearchEquipments': capacity_search_equipments,
			'requestId': request_id,
			'subject': f'{app_config.BOOKING_ASSISTANT_SNS_SUBJECT}',
			'className': f'{app_config.BOOKING_ASSISTANT_SNS_CLASS_NAME}',
			'autoInviteDetails': auto_invite_details
		}
		logger.debug(f"sending event {event} to {app_config.BOOKING_ASSISTANT_FLOW_QUEUE}")

		try:
			sqs_service = SqsService()
			return sqs_service.send(app_config.BOOKING_ASSISTANT_FLOW_QUEUE, json.dumps(event), app_config.BOOKING_ASSISTANT_DELAY_SECONDS)
		except Exception as e:
			logger.error(f"failed to send BookingAssistantFlowEvent message: {e}")
			logger.error(f"BookingAssistantFlowEvent message: {event}")



import unittest

from cc_py_commons.utils.lambda_utils import is_event_from_lambda_warmer


class TestLambdaUtils(unittest.TestCase):

	def test_event_from_lambda_warmer(self):
		event = {
			'version': '0',
			'id': 'f70d7afc-e2c0-cb53-10e7-43bcafc4c8fb',
			'detail-type': 'Scheduled Event',
			'source': 'aws.events',
			'account': '791608169866',
			'time': '2023-03-14T10:36:03Z',
			'region': 'us-west-1',
			'resources': ['arn:aws:events:us-west-1:791608169866:rule/BULK_LANE_PRICING_LAMBDA_WARMER_DEV'],
			'detail': {}
		}
		result = is_event_from_lambda_warmer(event)

		self.assertTrue(result)

	def test_event_not_from_lambda_warmer(self):
		event = {
			'Records': [],
		}
		result = is_event_from_lambda_warmer(event)

		self.assertFalse(result)



from dataclasses import dataclass, field

@dataclass
class Location:
        
    city: str
    state: str
    postcode: str
    county: str = field(default=None)
    country: str = field(default=None)
    latitude: float = field(default=None)
    longitude: float = field(default=None)


from marshmallow import fields, EXCLUDE
from cc_py_commons.schemas.camel_case_schema import CamelCaseSchema

class LocationSchema(CamelCaseSchema):
  class Meta:
      unknown = EXCLUDE
      
  city = fields.String()
  state = fields.String()
  postcode = fields.String(allow_none=True)
  county = fields.String(allow_none=True) 
  country = fields.String(allow_none=True)
  latitude = fields.Float(allow_none=True)
  longitude = fields.Float(allow_none=True)
  


import boto3

class SqsService:
	def send(self, queue_url, message, delaySeconds=0, messageGroupId=None):
		'''
		Sends a message to the specified queue and returns the messageId. 
		The messageId can be used to lookup and delete the message in the queue.
		'''
		sqs = boto3.client('sqs')
		if messageGroupId:
			response = sqs.send_message(
				QueueUrl=queue_url,
				MessageBody=message,
				DelaySeconds=delaySeconds,
				MessageAttributes={},
				MessageGroupId=messageGroupId
			)
		else:
			response = sqs.send_message(
				QueueUrl=queue_url,
				MessageBody=message,
				DelaySeconds=delaySeconds,
				MessageAttributes={}
			)
		return response.get('MessageId')



import json

from cc_py_commons.sns.sns_service import SnsService
from cc_py_commons.utils.logger_v2 import logger

class ParsedCarrierNotification:

  def __init__(self, app_config):
    self._app_config = app_config

  def send(self, parsed_carrier, c4_account_id, import_stats_id, request_id):
    message = {
      'accountId': c4_account_id,
      'parsedCarrier': parsed_carrier,
      'importStatsId': import_stats_id,
      'requestId': request_id,
      'subject': f'{self._app_config.PARSED_CARRIER_SNS_SUBJECT}',
      'className': f'{self._app_config.PARSED_CARRIER_SNS_CLASS_NAME}',
      'vettingSource': 'DFM'
    }
    logger.debug(f"sending message {message} to {self._app_config.PARSED_CARRIER_SNS_TOPIC_ARN}")

    sns_service = SnsService()
    sns_service.send(self._app_config.PARSED_CARRIER_SNS_TOPIC_ARN,
      self._app_config.PARSED_CARRIER_SNS_SUBJECT, json.dumps(message))



from marshmallow import fields, EXCLUDE, post_load
from cc_py_commons.schemas.camel_case_schema import CamelCaseSchema
from cc_py_commons.loads.equipment_schema import EquipmentSchema
from cc_py_commons.loads.location_schema import LocationSchema
from cc_py_commons.loads.freighthub_contact_schema import FreightHubContactSchema
from cc_py_commons.loads.load import Load

class LoadSchema(CamelCaseSchema):
    class Meta:
        unknown = EXCLUDE

    reference_number = fields.String()
    # C4 Account ID
    customer_id = fields.Integer(allow_none=True)
    origin = fields.Nested(LocationSchema)
    destination = fields.Nested(LocationSchema)
    pickup_date = fields.Date()
    delivery_date = fields.Date()
    status_id = fields.UUID()
    source_id = fields.UUID()
    equipment = fields.List(fields.Nested(EquipmentSchema))
    equipment_description = fields.String(allow_none=True)     
    contact = fields.Nested(FreightHubContactSchema, allow_none=True)
    pickup_open_time= fields.Time(allow_none=True)
    pickup_close_time= fields.Time(allow_none=True)
    pickup_appointment_required= fields.Boolean(missing=False, default=False)
    delivery_open_time= fields.Time(allow_none=True)
    delivery_close_time= fields.Time(allow_none=True)
    delivery_appointment_required= fields.Boolean(missing=False, default=False)
    tracking_number = fields.String(allow_none=True)
    full_load = fields.Boolean(allow_none=True, default=True, missing=True)
    length = fields.Integer(allow_none=True)
    width = fields.Integer(allow_none=True)
    height = fields.Integer(allow_none=True)
    weight = fields.Integer(allow_none=True)
    load_count = fields.Integer(allow_none=True)
    distance = fields.Integer(allow_none=True)
    stops_count = fields.Integer(allow_none=True)
    stops = fields.List(allow_none=True, cls_or_instance=fields.Raw())
    rate = fields.String(allow_none=True)
    declared_value = fields.Integer(allow_none=True)
    comment = fields.String(allow_none=True)
    commodity = fields.String(allow_none=True)
    min_temperature= fields.Float(allow_none=True)
    max_temperature= fields.Float(allow_none=True)
    tarp_size = fields.Integer(allow_none=True)
    carrier_id = fields.UUID(allow_none=True)
    contact_id = fields.UUID(allow_none=True)
    url = fields.String(allow_none=True)
    demo_load= fields.Boolean(missing=False, default=False)
    team_service_required= fields.Boolean(missing=False, default=False)
    quote_id = fields.UUID(allow_none=True)
    truck_lane_search_id = fields.UUID(allow_none=True)
    truck_search_id = fields.UUID(allow_none=True)
    # generated by server and returned
    id = fields.UUID(allow_none=True)
    # generated by server and returned
    load_number = fields.String(allow_none=True)
    mcleod_movement_id = fields.Integer(allow_none=True)
    origin_pallets_required = fields.Boolean(allow_none=True)
    destination_pallets_required = fields.Boolean(allow_none=True)
    hazmat = fields.Boolean(allow_none=True)
    origin_location_id = fields.String(allow_none=True)
    origin_location_name = fields.String(allow_none=True)
    destination_location_id = fields.String(allow_none=True)
    destination_location_name = fields.String(allow_none=True)
    customer_equipment_id = fields.String(allow_none=True)
    partial_load = fields.Boolean(allow_none=True, default=False, missing=False)
    pieces = fields.Integer(allow_none=True)
    available_time = fields.DateTime(allow_none=True)
    max_pay = fields.Integer(allow_none=True)
    linear_feet = fields.Integer(allow_none=True)
    account_id = fields.Integer(allow_none=True)
    revenue_code = fields.String(allow_none=True)
    customer_code = fields.String(allow_none=True)
    ltl = fields.Boolean(allow_none=True, default=False, missing=False)
    special_instructions = fields.String(allow_none=True)
    request_id = fields.UUID(allow_none=True)
    predicted_price: int = fields.Integer(allow_none=True)
    
    @post_load
    def make_load(self, data, **kwargs):
        return Load(**data)



import uuid
from dataclasses import dataclass, field

@dataclass
class Lane:

  trailer_type: str
  origin_city: str
  origin_state: str
  dest_city: str
  dest_state: str  
  origin_zip: str = field(default=None)
  origin_lat: float = field(default=None)
  origin_lng: float = field(default=None)
  origin_deadhead: float = field(default=None)
  dest_zip: str = field(default=None)
  destination_states: str = field(default=None)
  dest_lat: float = field(default=None)
  dest_lng: float = field(default=None)
  destination_deadhead: float = field(default=None)
  priced_loads: int = field(default=0)
  # generated by server
  id: uuid.UUID = field(default=None)


import unittest

from cc_py_commons.utils.temperature_utils import to_celsius


class TestTemperatureUtils(unittest.TestCase):

	def test_when_value_is_null(self):
		try:
			temp_in_celsius = to_celsius(None)
			self.assertIsNone(temp_in_celsius)
		except Exception as e:
			self.fail('test_when_value_is_null: Failed by throwing unexpected exception')

	def test_when_value_is_not_null(self):
		temp_in_celsius = to_celsius(65.0)

		self.assertEqual(18.33, temp_in_celsius)



# refer to the following for more info
# "https"://maps.alk.com/PCMDoc/Reports
# "https"://maps.alk.com/PCMDoc/CalcMilesReport

class PcMilerConfig():

    url = "https://pcmiler.alk.com/apis/rest/v1.0/Service.svc/route/routeReports"
    query_params = {
      "stops": None, # must be provided at query time
      "reports": "CalcMiles",
      "vehType": "Truck",
      "routeType": "Shortest",
      "hwyOnly": "true",
      "custRdSpeeds": "false",
      "avoidFavors": "false",
      "afSetIDs": "",
      "overrideClass": "FiftyThreeFoot",
      "distUnits": "Miles",
      "fuelUnits": "Gallons",
      "avoidTolls": "true",
      "inclFerryDist": "true",
      "openBorders": "true",
      "restrOverrides": "false",
      "hazMat": "",
      "routeOpt": "DestinationFixed",
      "lang": "ENUS",
      "hubRouting": "false",
      "vehDimUnits": "English",
      "vehHeight": "13'6\"",
      "vehLength": "53'",
      "vehWidth": "96\"",
      "vehWeight": "14000",
      "axles": "8",
      "truckConfig": "none",
      "LCV": "false",
      "inclTollData": "true",
      "fuelEconLoad": "8.5",
      "fuelEconEmpty": "11.9",
      "costPerFuelUnit": "13",
      "costGHG": "5.2",
      "costMaintLoad": "12.2",
      "costMaintEmpty": "8.9",
      "costTimeLoad": "15.5",
      "costTimeEmpty": "12.6",
      "exchangeRate": "1.01",
      "tollPlan": "ezpass",
      "region": "NA",
      "dataVersion": "current",
      "authToken": None
    }



import json
import requests

from cc_py_commons.utils.logger_v2 import logger
from .constants import C4_API_AUTH_TOKEN, C4_API_URL


def execute(account_id):
	url = f"{C4_API_URL}/amazonFreight/refreshToken/{account_id}"
	token = f"Bearer {C4_API_AUTH_TOKEN}"
	headers = {
		"Authorization": token
	}
	response = requests.get(url, headers=headers)

	if response.status_code != 200:
		logger.warning(f"Request to refresh Amazon token failed with status code: {response.status_code}")
		return None

	json_response = response.json()
	data_json_string = json_response.get('data', {}).get('data')
	return json.loads(data_json_string) if data_json_string else None



import requests
import os
from dateutil.parser import parse

from cc_py_commons.utils import json_logger
from cc_py_commons.quotes.quote_schema import QuoteSchema

BOOKING_AGENT_URL = os.environ.get('BOOKING_AGENT_URL')
BOOKING_AGENT_TOKEN = os.environ.get("BOOKING_AGENT_TOKEN")


def execute(account_id, filters_dict):
	url = f"{BOOKING_AGENT_URL}/quote"
	token = f"Bearer {BOOKING_AGENT_TOKEN}"
	headers = {
		"Authorization": token
	}
	json_logger.debug(account_id, f"Requesting quotes from booking-agent", url=url, filters=filters_dict)
	response = requests.get(url, headers=headers, params=filters_dict)
	quotes = []
	if response.status_code == 200:
		quotes = response.json()['content']
		for quote in quotes:
			quote['pickupDate'] = parse(quote['pickupDate']).strftime('%Y-%m-%d')
			quote['deliveryDate'] = parse(quote['deliveryDate']).strftime('%Y-%m-%d')
		quotes = QuoteSchema().load(quotes, many=True)
	return quotes



import os

class Config(object):
  """
  Parent configuration class.

  Add all config attributes in the parent class with a default.
  Then override as needed in the environment specific configs
  """
  AWS_ACCESS_KEY_ID = os.environ.get("AWS_ACCESS_KEY_ID")
  AWS_SECRET_ACCESS_KEY = os.environ.get("AWS_SECRET_ACCESS_KEY")
  ACCESS_KEY_ID=os.environ.get("ACCESS_KEY_ID")
  SECRET_ACCESS_KEY=os.environ.get("SECRET_ACCESS_KEY")
  LOG_APP_NAME= os.getenv('LOG_APP_NAME')
  LOG_LEVEL = os.environ.get('LOG_LEVEL', 'INFO')
  GOOGLE_API_KEY = os.getenv('GOOGLE_API_KEY')
  PC_MILER_URL = "https://pcmiler.alk.com/apis/rest/v1.0/Service.svc/locations?postcodeFilter={0}&dataset=Current&authToken={1}"
  PC_MILER_KEY = os.getenv('PC_MILER_KEY')
  LOCATION_REDIS_URL = os.getenv('LOCATION_REDIS_URL')
  LOCATION_REDIS_PWD = os.getenv('LOCATION_REDIS_PWD')
  DISTANCE_CACHE_URL = os.getenv('DISTANCE_CACHE_URL')
  DISTANCE_CACHE_PASSWORD = os.getenv('DISTANCE_CACHE_PASSWORD')
  TIMEZONE_CACHE_URL = os.getenv('TIMEZONE_CACHE_URL')
  TIMEZONE_CACHE_PASSWORD = os.getenv('TIMEZONE_CACHE_PASSWORD')
  PC_MILER_HOURLY_LIMIT = 14000
  PC_MILER_MONTHLY_LIMIT = 300000
  PARSED_CARRIER_SNS_TOPIC_ARN = 'arn:aws:sns:us-west-1:791608169866:carrier-hub-sns-test'
  PARSED_CARRIER_SNS_SUBJECT = 'parsed-carrier'
  PARSED_CARRIER_SNS_CLASS_NAME = 'com.cargochief.sdk.carrierhub.notifications.ParsedCarrierNotification'
  BOOK_LOAD_SNS_TOPIC_ARN = 'arn:aws:sns:us-west-1:791608169866:booking-agent-book-load-test'
  BOOK_LOAD_SNS_SUBJECT = 'book-load'
  BOOK_LOAD_SNS_CLASS_NAME = 'com.cargochief.sdk.bookingagent.sns.BookLoadNotification'
  BOOKING_ASSISTANT_SNS_TOPIC_ARN = 'arn:aws:sns:us-west-1:791608169866:booking-assistant-flow-test'
  BOOKING_ASSISTANT_SNS_SUBJECT = 'booking-assistant-flow'
  BOOKING_ASSISTANT_SNS_CLASS_NAME = 'com.cargochief.sdk.bookingagent.sns.BookingAssistantFlowNotification'
  IMPORT_MOVEMENTS_SNS_TOPIC_ARN = 'arn:aws:sns:us-west-1:791608169866:mcleod-import-movements-test'
  IMPORT_MOVEMENTS_SNS_SUBJECT = 'import-movements'
  IMPORT_MOVEMENTS_SNS_CLASS_NAME = 'com.cargochief.sdk.c4.sns.mcleod.ImportMovementsNotification'
  IMPORT_CARRIERS_SNS_SUBJECT = 'import-carriers'
  IMPORT_CARRIERS_SNS_TOPIC_ARN = 'arn:aws:sns:us-west-2:791608169866:mcleod-import-carriers-test'
  MINIMUM_MILES_PER_DAY = int(os.getenv('MINIMUM_MILES_PER_DAY', 300))
  BOOKING_ASSISTANT_FLOW_QUEUE='https://sqs.us-west-1.amazonaws.com/791608169866/booking-agent-worker-test'
  BOOKING_ASSISTANT_DELAY_SECONDS=os.environ.get('BOOKING_ASSISTANT_DELAY_SECONDS', 0)
  TURVO_LOADS_BUCKET = 'turvo-loads-dev'
  ALJEX_LOADS_BUCKET = 'aljex-loads-dev'
  KNOWN_CLIENT_FILE_EXTENSIONS = {
    'surgetransportation.com': '6507',
    'simplelgx.com': '7084',
    'engaged': '7147',
    'amstanc4activecarrierlist': '7267',
    'us foods xlsextract': '7582',
    'clservicesinc.com': '7310',
    'zengistics': '7649'
  }
  BID_COUNTER_FAILURE_SNS_CLASS_NAME = 'com.cargochief.sdk.bookingagent.sns.BidCounterFailureNotification'
  BOOKING_AGENT_SNS_ARN = 'arn:aws:sns:us-west-1:791608169866:booking-agent-sns-test'
  CARRIER_HUB_SNS_ARN = 'arn:aws:sns:us-west-1:791608169866:carrier-hub-sns-test'
  HERMES_SNS_ARN = 'arn:aws:sns:us-west-1:791608169866:hermes-sns-test'
  C4_ACCOUNTS_BUCKET = 'c4-accounts-test'
  ANALYTICS_SNS_ARN = 'arn:aws:sns:us-west-1:791608169866:analytics-test'

  # Database
  DB_USERNAME = os.getenv('DB_USERNAME')
  DB_HOST = os.getenv('DB_HOST')
  DB_PORT = os.getenv('DB_PORT')
  DB_PASSWORD = os.getenv('DB_PASSWORD')
  DB_NAME = os.getenv('DB_NAME')

  # Services
  CARRIER_HUB_URL = os.environ.get('CARRIER_HUB_URL')
  CARRIER_HUB_AUTH_TOKEN = os.environ.get("CARRIER_HUB_AUTH_TOKEN")
  DD_API_KEY=os.environ.get('DD_API_KEY')
  DD_SITE=os.environ.get('DD_SITE')

class LocalConfig(Config):
  """Configurations for running and debugging locally, with a separate local database."""
  LOCATION_REDIS_URL='redis://localhost:6379'
  LOCATION_REDIS_PWD=None
  DISTANCE_CACHE_URL='redis://localhost:6379'
  DISTANCE_CACHE_PASSWORD=None
  TIMEZONE_CACHE_URL='redis://localhost:6379'
  TIMEZONE_CACHE_PASSWORD=None

class DevelopmentConfig(Config):
  """Configurations for running in dev mode, with a remote database."""
  
class StagingConfig(Config):
  """Configurations for running in dev mode, with a remote database."""
  BOOK_LOAD_SNS_TOPIC_ARN = 'arn:aws:sns:us-west-2:791608169866:booking-agent-book-load-staging'
  BOOKING_ASSISTANT_SNS_TOPIC_ARN = 'arn:aws:sns:us-west-2:791608169866:booking-assistant-flow-staging'
  IMPORT_MOVEMENTS_SNS_TOPIC_ARN = 'arn:aws:sns:us-west-2:791608169866:mcleod-import-movements-staging'
  PARSED_CARRIER_SNS_TOPIC_ARN = 'arn:aws:sns:us-west-2:791608169866:mcleod-parsed-carrier-staging'
  IMPORT_CARRIERS_SNS_TOPIC_ARN = 'arn:aws:sns:us-west-2:791608169866:mcleod-import-carriers-staging'
  BOOKING_ASSISTANT_FLOW_QUEUE='https://sqs.us-west-2.amazonaws.com/791608169866/booking-agent-worker-staging'

class ProductionConfig(Config):
  """Configurations for running in dev mode, with a remote database."""
  PARSED_CARRIER_SNS_TOPIC_ARN = 'arn:aws:sns:us-west-1:791608169866:mcleod-parsed-carrier-prod'
  BOOK_LOAD_SNS_TOPIC_ARN = 'arn:aws:sns:us-west-1:791608169866:booking-agent-book-load-prod'
  BOOKING_ASSISTANT_SNS_TOPIC_ARN = 'arn:aws:sns:us-west-1:791608169866:booking-assistant-flow-prod'
  IMPORT_MOVEMENTS_SNS_TOPIC_ARN = 'arn:aws:sns:us-west-1:791608169866:mcleod-import-movements-prod'
  IMPORT_CARRIERS_SNS_TOPIC_ARN = 'arn:aws:sns:us-west-1:791608169866:mcleod-import-carriers-prod'
  BOOKING_ASSISTANT_FLOW_QUEUE='https://sqs.us-west-1.amazonaws.com/791608169866/awseb-e-3dhx3ncwcd-stack-AWSEBWorkerQueue-129YBH2WM1TD0'
  TURVO_LOADS_BUCKET = 'turvo-loads-prod'
  ALJEX_LOADS_BUCKET = 'aljex-loads-prod'
  KNOWN_CLIENT_FILE_EXTENSIONS = {
    'surgetransportation.com': '6615',
    'simplelgx.com': '7084',
    'engaged': '7147',
    'amstanc4activecarrierlist': '7267',
    'us foods xlsextract': '7582',
    'clservicesinc.com': '7310',
    'zengistics': '7649'
  }
  BOOKING_AGENT_SNS_ARN = 'arn:aws:sns:us-west-1:791608169866:booking-agent-sns-prod'
  CARRIER_HUB_SNS_ARN = 'arn:aws:sns:us-west-1:791608169866:carrier-hub-sns-prod'
  HERMES_SNS_ARN = 'arn:aws:sns:us-west-1:791608169866:hermes-sns-prod'
  C4_ACCOUNTS_BUCKET = 'c4-accounts-prod'
  ANALYTICS_SNS_ARN ='arn:aws:sns:us-west-1:791608169866:analytics-prod'

config_options = {
    'local': LocalConfig,
    'development': DevelopmentConfig,
    'staging': StagingConfig,
    'production': ProductionConfig,
}

env_name = os.getenv('APP_SETTINGS')

if not env_name:
  print("warning: No APP_SETTINGS environment variable set, using development")
  env_name = 'development'

app_config = config_options[env_name]



import logging
import requests
import json
import socket
from datetime import datetime

from cc_py_commons.config.env import env_name, app_config

class DataDogLogHandler(logging.Handler):
	"""
	Logs to DataDog
	Requires DD_SITE and DD_API_KEY ENV variables
	"""
	def __init__(self):
		super().__init__() 
		self.api_key = app_config.DD_API_KEY
		self.headers = {
				'Content-Type': 'application/json',
				'DD-API-KEY': self.api_key,
		}
		self.dd_url = f"https://http-intake.logs.{app_config.DD_SITE}/api/v2/logs"
		self.hostname = socket.gethostname()

	def emit(self, record):
		try:
			message = self.format(record)
			log_entry = {
					'ddsource': 'python',
					'service': app_config.LOG_APP_NAME,
					'hostname': self.hostname,
					'ddtags': f"env:{env_name}",
					'message': message,
					'timestamp': datetime.utcnow().isoformat() + 'Z'  # UTC timestamp in ISO8601
			}
			response = requests.post(self.dd_url, headers=self.headers, data=json.dumps([log_entry]))

			if response.status_code != 200 and response.status_code != 202:
					raise Exception(f'Error posting log to DataDog: {response.text}')
		except Exception:
			self.handleError(record)
			


import uuid
import datetime
from dataclasses import dataclass, field
from typing import List

from cc_py_commons.loads.location import Location
from cc_py_commons.loads.equipment import Equipment
from cc_py_commons.loads.freighthub_contact import FreightHubContact

@dataclass
class Load:
    """
    Representation of a freight-hub load.
    In freight-hub customer_id = C4 Account ID
    source_id comes from the freight-hub sources
    """
    reference_number: str
    # C4 User ID
    customer_id: int
    origin: Location
    destination: Location
    pickup_date: datetime.date
    delivery_date: datetime.date
    status_id: uuid.UUID
    source_id: uuid.UUID
    equipment: List[Equipment]
    equipment_description: str     
    contact: FreightHubContact
    pickup_open_time: datetime.time = field(default=None)
    pickup_close_time: datetime.time = field(default=None)
    pickup_appointment_required: bool = field(default=False)
    delivery_open_time: datetime.time = field(default=None)
    delivery_close_time: datetime.time = field(default=None)
    delivery_appointment_required: bool = field(default=False)
    tracking_number: str = field(default=None)
    full_load: bool = field(default=True)
    length: int = field(default=None)
    width: int = field(default=None)
    height: int = field(default=None)
    weight: int = field(default=None)
    load_count: int = field(default=None)
    distance: int = field(default=None)
    stops_count: int = field(default=None)
    stops: list = field(default=None)
    rate: str = field(default=None)
    declared_value: int = field(default=None)
    comment: str = field(default=None)
    commodity: str = field(default=None)
    min_temperature: float = field(default=None)
    max_temperature: float = field(default=None)
    tarp_size: int = field(default=None)
    carrier_id: uuid.UUID = field(default=None)
    contact_id: uuid.UUID = field(default=None)
    url: str = field(default=None)
    demo_load: bool = field(default=False)
    team_service_required: bool = field(default=False)
    quote_id: uuid.UUID = field(default=None)
    truck_lane_search_id: uuid.UUID = field(default=None)
    truck_search_id: uuid.UUID = field(default=None)
    # generated by server and returned
    id: uuid.UUID = field(default=None)
    # generated by server and returned
    load_number: str = field(default=None)
    mcleod_movement_id: str = field(default=None)
    origin_pallets_required: bool = field(default=False)
    destination_pallets_required: bool = field(default=False)
    hazmat: bool = field(default=False)
    origin_location_id: str = field(default=None)
    origin_location_name: str = field(default=None)
    destination_location_id: str = field(default=None)
    destination_location_name: str = field(default=None)
    special_instructions: dict = field(default=None)
    customer_equipment_id: str = field(default=None)
    partial_load: bool = field(default=False)
    pieces: int = field(default=None)
    available_time: datetime.datetime = field(default=None)
    account_id: int = field(default=None)
    max_pay: int = field(default=None)
    linear_feet: int = field(default=None)
    revenue_code: str = field(default=None)
    customer_code: str = field(default=None)
    ltl: bool = field(default=False)
    request_id: uuid.UUID = field(default=None)
    predicted_price: int = field(default=None)



from setuptools import setup, find_packages

setup(
    name='cc_py_commons',
    description='Common code for microservices',
    version='0.5.29',
    url='https://github.com/Cargo-Chief/py-commons',
    author='CargoChief',
    author_email='engineering@cargochief.com',
    packages=find_packages(),
    install_requires=['requests', 'googlemaps', 'marshmallow', 'dataclasses', 'boto3', 'inflection', 'pytz'],
    keywords=[]
    )



import os, sys, json
import logging
import socket
from logging import StreamHandler
from logging.handlers import SysLogHandler

from cc_py_commons.config.env import env_name, app_config

## DEPRECATED. Use logger_v2 instead
class ContextFilter(logging.Filter):
  hostname = socket.gethostname()

  def filter(self, record):
    record.hostname = ContextFilter.hostname
    return True

def _config_logger():
  logger = logging.getLogger(app_config.LOG_APP_NAME)
  logger.setLevel(app_config.LOG_LEVEL)

  contextFilter = ContextFilter()
  logger.addFilter(contextFilter)
  formatter = logging.Formatter('{}: %(levelname)s %(message)s'.format(app_config.LOG_APP_NAME),
                            datefmt='%Y-%m-%d %I:%M:%S %p')

  if env_name == 'local':
    syslog = StreamHandler()
  else:
    syslog = SysLogHandler(address=('logs3.papertrailapp.com', 10024))

  syslog.setFormatter(formatter)

  if not logger.handlers:
    logger.addHandler(syslog)

  return logger

logger = _config_logger()



import requests

from cc_py_commons.utils.logger_v2 import logger
from .constants import C4_API_AUTH_TOKEN, C4_API_URL


def execute():
	url = f"{C4_API_URL}/amazonFreight/sessionToken"
	token = f"Bearer {C4_API_AUTH_TOKEN}"
	headers = {
		"Authorization": token
	}
	response = requests.get(url, headers=headers)

	if response.status_code != 200:
		logger.warning(f"Request to get Amazon session token failed with status code: {response.status_code}")
		return None

	return response.json()
